@@ -1,5 +1,5 @@
 from json import dumps, loads
-
+import sys
 from jaseci.utils.utils import find_class_and_import
 
 
@@ -212,6 +212,9 @@ class MemoryHook:
                 dist[t] = 1
         return dist
 
+    def mem_size(self):
+        return sys.getsizeof(self.mem) / 1024
+
     ###################################################
     #                  CLASS CONTROL                  #
     ###################################################
